@@ -12,17 +12,23 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from datetime import datetime
+from typing import Dict, List, Sequence, Union
 
 from .literals import (
     BatteryLevelType,
     ConnectionStatusType,
     DeviceStateType,
+    DlClassType,
+    EventNotificationTopicStatusType,
     EventType,
     ExpressionTypeType,
+    FuotaDeviceStatusType,
+    FuotaTaskStatusType,
     LogLevelType,
     MessageTypeType,
     SigningAlgType,
+    SupportedRfRegionType,
     WirelessDeviceEventType,
     WirelessDeviceIdTypeType,
     WirelessDeviceTypeType,
@@ -32,11 +38,11 @@ from .literals import (
     WirelessGatewayTaskStatusType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -47,15 +53,23 @@ __all__ = (
     "AbpV1_1TypeDef",
     "AssociateAwsAccountWithPartnerAccountRequestRequestTypeDef",
     "AssociateAwsAccountWithPartnerAccountResponseTypeDef",
+    "AssociateMulticastGroupWithFuotaTaskRequestRequestTypeDef",
+    "AssociateWirelessDeviceWithFuotaTaskRequestRequestTypeDef",
+    "AssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
     "AssociateWirelessDeviceWithThingRequestRequestTypeDef",
     "AssociateWirelessGatewayWithCertificateRequestRequestTypeDef",
     "AssociateWirelessGatewayWithCertificateResponseTypeDef",
     "AssociateWirelessGatewayWithThingRequestRequestTypeDef",
+    "CancelMulticastGroupSessionRequestRequestTypeDef",
     "CertificateListTypeDef",
     "CreateDestinationRequestRequestTypeDef",
     "CreateDestinationResponseTypeDef",
     "CreateDeviceProfileRequestRequestTypeDef",
     "CreateDeviceProfileResponseTypeDef",
+    "CreateFuotaTaskRequestRequestTypeDef",
+    "CreateFuotaTaskResponseTypeDef",
+    "CreateMulticastGroupRequestRequestTypeDef",
+    "CreateMulticastGroupResponseTypeDef",
     "CreateServiceProfileRequestRequestTypeDef",
     "CreateServiceProfileResponseTypeDef",
     "CreateWirelessDeviceRequestRequestTypeDef",
@@ -68,6 +82,8 @@ __all__ = (
     "CreateWirelessGatewayTaskResponseTypeDef",
     "DeleteDestinationRequestRequestTypeDef",
     "DeleteDeviceProfileRequestRequestTypeDef",
+    "DeleteFuotaTaskRequestRequestTypeDef",
+    "DeleteMulticastGroupRequestRequestTypeDef",
     "DeleteServiceProfileRequestRequestTypeDef",
     "DeleteWirelessDeviceRequestRequestTypeDef",
     "DeleteWirelessGatewayRequestRequestTypeDef",
@@ -75,17 +91,31 @@ __all__ = (
     "DeleteWirelessGatewayTaskRequestRequestTypeDef",
     "DestinationsTypeDef",
     "DeviceProfileTypeDef",
+    "DeviceRegistrationStateEventConfigurationTypeDef",
     "DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef",
+    "DisassociateMulticastGroupFromFuotaTaskRequestRequestTypeDef",
+    "DisassociateWirelessDeviceFromFuotaTaskRequestRequestTypeDef",
+    "DisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
     "DisassociateWirelessDeviceFromThingRequestRequestTypeDef",
     "DisassociateWirelessGatewayFromCertificateRequestRequestTypeDef",
     "DisassociateWirelessGatewayFromThingRequestRequestTypeDef",
+    "FPortsTypeDef",
+    "FuotaTaskTypeDef",
     "GetDestinationRequestRequestTypeDef",
     "GetDestinationResponseTypeDef",
     "GetDeviceProfileRequestRequestTypeDef",
     "GetDeviceProfileResponseTypeDef",
+    "GetFuotaTaskRequestRequestTypeDef",
+    "GetFuotaTaskResponseTypeDef",
     "GetLogLevelsByResourceTypesResponseTypeDef",
+    "GetMulticastGroupRequestRequestTypeDef",
+    "GetMulticastGroupResponseTypeDef",
+    "GetMulticastGroupSessionRequestRequestTypeDef",
+    "GetMulticastGroupSessionResponseTypeDef",
     "GetPartnerAccountRequestRequestTypeDef",
     "GetPartnerAccountResponseTypeDef",
+    "GetResourceEventConfigurationRequestRequestTypeDef",
+    "GetResourceEventConfigurationResponseTypeDef",
     "GetResourceLogLevelRequestRequestTypeDef",
     "GetResourceLogLevelResponseTypeDef",
     "GetServiceEndpointRequestRequestTypeDef",
@@ -112,6 +142,12 @@ __all__ = (
     "ListDestinationsResponseTypeDef",
     "ListDeviceProfilesRequestRequestTypeDef",
     "ListDeviceProfilesResponseTypeDef",
+    "ListFuotaTasksRequestRequestTypeDef",
+    "ListFuotaTasksResponseTypeDef",
+    "ListMulticastGroupsByFuotaTaskRequestRequestTypeDef",
+    "ListMulticastGroupsByFuotaTaskResponseTypeDef",
+    "ListMulticastGroupsRequestRequestTypeDef",
+    "ListMulticastGroupsResponseTypeDef",
     "ListPartnerAccountsRequestRequestTypeDef",
     "ListPartnerAccountsResponseTypeDef",
     "ListServiceProfilesRequestRequestTypeDef",
@@ -127,22 +163,35 @@ __all__ = (
     "LoRaWANDeviceMetadataTypeDef",
     "LoRaWANDeviceProfileTypeDef",
     "LoRaWANDeviceTypeDef",
+    "LoRaWANFuotaTaskGetInfoTypeDef",
+    "LoRaWANFuotaTaskTypeDef",
     "LoRaWANGatewayCurrentVersionTypeDef",
     "LoRaWANGatewayMetadataTypeDef",
     "LoRaWANGatewayTypeDef",
     "LoRaWANGatewayVersionTypeDef",
     "LoRaWANGetServiceProfileInfoTypeDef",
     "LoRaWANListDeviceTypeDef",
+    "LoRaWANMulticastGetTypeDef",
+    "LoRaWANMulticastMetadataTypeDef",
+    "LoRaWANMulticastSessionTypeDef",
+    "LoRaWANMulticastTypeDef",
     "LoRaWANSendDataToDeviceTypeDef",
     "LoRaWANServiceProfileTypeDef",
+    "LoRaWANStartFuotaTaskTypeDef",
     "LoRaWANUpdateDeviceTypeDef",
     "LoRaWANUpdateGatewayTaskCreateTypeDef",
     "LoRaWANUpdateGatewayTaskEntryTypeDef",
+    "MulticastGroupByFuotaTaskTypeDef",
+    "MulticastGroupTypeDef",
+    "MulticastWirelessMetadataTypeDef",
     "OtaaV1_0_xTypeDef",
     "OtaaV1_1TypeDef",
+    "ProximityEventConfigurationTypeDef",
     "PutResourceLogLevelRequestRequestTypeDef",
     "ResetResourceLogLevelRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "SendDataToMulticastGroupRequestRequestTypeDef",
+    "SendDataToMulticastGroupResponseTypeDef",
     "SendDataToWirelessDeviceRequestRequestTypeDef",
     "SendDataToWirelessDeviceResponseTypeDef",
     "ServiceProfileTypeDef",
@@ -152,17 +201,25 @@ __all__ = (
     "SidewalkAccountInfoWithFingerprintTypeDef",
     "SidewalkDeviceMetadataTypeDef",
     "SidewalkDeviceTypeDef",
+    "SidewalkEventNotificationConfigurationsTypeDef",
     "SidewalkListDeviceTypeDef",
     "SidewalkSendDataToDeviceTypeDef",
     "SidewalkUpdateAccountTypeDef",
+    "StartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
+    "StartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
+    "StartFuotaTaskRequestRequestTypeDef",
+    "StartMulticastGroupSessionRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "TestWirelessDeviceRequestRequestTypeDef",
     "TestWirelessDeviceResponseTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateDestinationRequestRequestTypeDef",
+    "UpdateFuotaTaskRequestRequestTypeDef",
     "UpdateLogLevelsByResourceTypesRequestRequestTypeDef",
+    "UpdateMulticastGroupRequestRequestTypeDef",
     "UpdatePartnerAccountRequestRequestTypeDef",
+    "UpdateResourceEventConfigurationRequestRequestTypeDef",
     "UpdateWirelessDeviceRequestRequestTypeDef",
     "UpdateWirelessGatewayRequestRequestTypeDef",
     "UpdateWirelessGatewayTaskCreateTypeDef",
@@ -204,7 +261,7 @@ _OptionalAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef = TypedDict(
     "_OptionalAssociateAwsAccountWithPartnerAccountRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -226,6 +283,30 @@ AssociateAwsAccountWithPartnerAccountResponseTypeDef = TypedDict(
     },
 )
 
+AssociateMulticastGroupWithFuotaTaskRequestRequestTypeDef = TypedDict(
+    "AssociateMulticastGroupWithFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+        "MulticastGroupId": str,
+    },
+)
+
+AssociateWirelessDeviceWithFuotaTaskRequestRequestTypeDef = TypedDict(
+    "AssociateWirelessDeviceWithFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+        "WirelessDeviceId": str,
+    },
+)
+
+AssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef = TypedDict(
+    "AssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+        "WirelessDeviceId": str,
+    },
+)
+
 AssociateWirelessDeviceWithThingRequestRequestTypeDef = TypedDict(
     "AssociateWirelessDeviceWithThingRequestRequestTypeDef",
     {
@@ -258,6 +339,13 @@ AssociateWirelessGatewayWithThingRequestRequestTypeDef = TypedDict(
     },
 )
 
+CancelMulticastGroupSessionRequestRequestTypeDef = TypedDict(
+    "CancelMulticastGroupSessionRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 CertificateListTypeDef = TypedDict(
     "CertificateListTypeDef",
     {
@@ -279,7 +367,7 @@ _OptionalCreateDestinationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDestinationRequestRequestTypeDef",
     {
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ClientRequestToken": str,
     },
     total=False,
@@ -306,7 +394,7 @@ CreateDeviceProfileRequestRequestTypeDef = TypedDict(
     {
         "Name": str,
         "LoRaWAN": "LoRaWANDeviceProfileTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ClientRequestToken": str,
     },
     total=False,
@@ -321,12 +409,81 @@ CreateDeviceProfileResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateFuotaTaskRequestRequestTypeDef",
+    {
+        "FirmwareUpdateImage": str,
+        "FirmwareUpdateRole": str,
+    },
+)
+_OptionalCreateFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateFuotaTaskRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "ClientRequestToken": str,
+        "LoRaWAN": "LoRaWANFuotaTaskTypeDef",
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateFuotaTaskRequestRequestTypeDef(
+    _RequiredCreateFuotaTaskRequestRequestTypeDef, _OptionalCreateFuotaTaskRequestRequestTypeDef
+):
+    pass
+
+
+CreateFuotaTaskResponseTypeDef = TypedDict(
+    "CreateFuotaTaskResponseTypeDef",
+    {
+        "Arn": str,
+        "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateMulticastGroupRequestRequestTypeDef",
+    {
+        "LoRaWAN": "LoRaWANMulticastTypeDef",
+    },
+)
+_OptionalCreateMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateMulticastGroupRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "ClientRequestToken": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateMulticastGroupRequestRequestTypeDef(
+    _RequiredCreateMulticastGroupRequestRequestTypeDef,
+    _OptionalCreateMulticastGroupRequestRequestTypeDef,
+):
+    pass
+
+
+CreateMulticastGroupResponseTypeDef = TypedDict(
+    "CreateMulticastGroupResponseTypeDef",
+    {
+        "Arn": str,
+        "Id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CreateServiceProfileRequestRequestTypeDef = TypedDict(
     "CreateServiceProfileRequestRequestTypeDef",
     {
         "Name": str,
         "LoRaWAN": "LoRaWANServiceProfileTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ClientRequestToken": str,
     },
     total=False,
@@ -355,7 +512,7 @@ _OptionalCreateWirelessDeviceRequestRequestTypeDef = TypedDict(
         "Description": str,
         "ClientRequestToken": str,
         "LoRaWAN": "LoRaWANDeviceTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -388,7 +545,7 @@ _OptionalCreateWirelessGatewayRequestRequestTypeDef = TypedDict(
     {
         "Name": str,
         "Description": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ClientRequestToken": str,
     },
     total=False,
@@ -423,7 +580,7 @@ _OptionalCreateWirelessGatewayTaskDefinitionRequestRequestTypeDef = TypedDict(
         "Name": str,
         "Update": "UpdateWirelessGatewayTaskCreateTypeDef",
         "ClientRequestToken": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -476,6 +633,20 @@ DeleteDeviceProfileRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteFuotaTaskRequestRequestTypeDef = TypedDict(
+    "DeleteFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+DeleteMulticastGroupRequestRequestTypeDef = TypedDict(
+    "DeleteMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
 DeleteServiceProfileRequestRequestTypeDef = TypedDict(
     "DeleteServiceProfileRequestRequestTypeDef",
     {
@@ -534,6 +705,14 @@ DeviceProfileTypeDef = TypedDict(
     total=False,
 )
 
+DeviceRegistrationStateEventConfigurationTypeDef = TypedDict(
+    "DeviceRegistrationStateEventConfigurationTypeDef",
+    {
+        "Sidewalk": "SidewalkEventNotificationConfigurationsTypeDef",
+    },
+    total=False,
+)
+
 DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef = TypedDict(
     "DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef",
     {
@@ -542,6 +721,30 @@ DisassociateAwsAccountFromPartnerAccountRequestRequestTypeDef = TypedDict(
     },
 )
 
+DisassociateMulticastGroupFromFuotaTaskRequestRequestTypeDef = TypedDict(
+    "DisassociateMulticastGroupFromFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+        "MulticastGroupId": str,
+    },
+)
+
+DisassociateWirelessDeviceFromFuotaTaskRequestRequestTypeDef = TypedDict(
+    "DisassociateWirelessDeviceFromFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+        "WirelessDeviceId": str,
+    },
+)
+
+DisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef = TypedDict(
+    "DisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+        "WirelessDeviceId": str,
+    },
+)
+
 DisassociateWirelessDeviceFromThingRequestRequestTypeDef = TypedDict(
     "DisassociateWirelessDeviceFromThingRequestRequestTypeDef",
     {
@@ -563,6 +766,26 @@ DisassociateWirelessGatewayFromThingRequestRequestTypeDef = TypedDict(
     },
 )
 
+FPortsTypeDef = TypedDict(
+    "FPortsTypeDef",
+    {
+        "Fuota": int,
+        "Multicast": int,
+        "ClockSync": int,
+    },
+    total=False,
+)
+
+FuotaTaskTypeDef = TypedDict(
+    "FuotaTaskTypeDef",
+    {
+        "Id": str,
+        "Arn": str,
+        "Name": str,
+    },
+    total=False,
+)
+
 GetDestinationRequestRequestTypeDef = TypedDict(
     "GetDestinationRequestRequestTypeDef",
     {
@@ -601,6 +824,29 @@ GetDeviceProfileResponseTypeDef = TypedDict(
     },
 )
 
+GetFuotaTaskRequestRequestTypeDef = TypedDict(
+    "GetFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+GetFuotaTaskResponseTypeDef = TypedDict(
+    "GetFuotaTaskResponseTypeDef",
+    {
+        "Arn": str,
+        "Id": str,
+        "Status": FuotaTaskStatusType,
+        "Name": str,
+        "Description": str,
+        "LoRaWAN": "LoRaWANFuotaTaskGetInfoTypeDef",
+        "FirmwareUpdateImage": str,
+        "FirmwareUpdateRole": str,
+        "CreatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetLogLevelsByResourceTypesResponseTypeDef = TypedDict(
     "GetLogLevelsByResourceTypesResponseTypeDef",
     {
@@ -611,6 +857,42 @@ GetLogLevelsByResourceTypesResponseTypeDef = TypedDict(
     },
 )
 
+GetMulticastGroupRequestRequestTypeDef = TypedDict(
+    "GetMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+GetMulticastGroupResponseTypeDef = TypedDict(
+    "GetMulticastGroupResponseTypeDef",
+    {
+        "Arn": str,
+        "Id": str,
+        "Name": str,
+        "Description": str,
+        "Status": str,
+        "LoRaWAN": "LoRaWANMulticastGetTypeDef",
+        "CreatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+GetMulticastGroupSessionRequestRequestTypeDef = TypedDict(
+    "GetMulticastGroupSessionRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+
+GetMulticastGroupSessionResponseTypeDef = TypedDict(
+    "GetMulticastGroupSessionResponseTypeDef",
+    {
+        "LoRaWAN": "LoRaWANMulticastSessionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetPartnerAccountRequestRequestTypeDef = TypedDict(
     "GetPartnerAccountRequestRequestTypeDef",
     {
@@ -628,6 +910,38 @@ GetPartnerAccountResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredGetResourceEventConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredGetResourceEventConfigurationRequestRequestTypeDef",
+    {
+        "Identifier": str,
+        "IdentifierType": Literal["PartnerAccountId"],
+    },
+)
+_OptionalGetResourceEventConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalGetResourceEventConfigurationRequestRequestTypeDef",
+    {
+        "PartnerType": Literal["Sidewalk"],
+    },
+    total=False,
+)
+
+
+class GetResourceEventConfigurationRequestRequestTypeDef(
+    _RequiredGetResourceEventConfigurationRequestRequestTypeDef,
+    _OptionalGetResourceEventConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
+GetResourceEventConfigurationResponseTypeDef = TypedDict(
+    "GetResourceEventConfigurationResponseTypeDef",
+    {
+        "DeviceRegistrationState": "DeviceRegistrationStateEventConfigurationTypeDef",
+        "Proximity": "ProximityEventConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetResourceLogLevelRequestRequestTypeDef = TypedDict(
     "GetResourceLogLevelRequestRequestTypeDef",
     {
@@ -866,6 +1180,74 @@ ListDeviceProfilesResponseTypeDef = TypedDict(
     },
 )
 
+ListFuotaTasksRequestRequestTypeDef = TypedDict(
+    "ListFuotaTasksRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListFuotaTasksResponseTypeDef = TypedDict(
+    "ListFuotaTasksResponseTypeDef",
+    {
+        "NextToken": str,
+        "FuotaTaskList": List["FuotaTaskTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredListMulticastGroupsByFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredListMulticastGroupsByFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalListMulticastGroupsByFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalListMulticastGroupsByFuotaTaskRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+
+class ListMulticastGroupsByFuotaTaskRequestRequestTypeDef(
+    _RequiredListMulticastGroupsByFuotaTaskRequestRequestTypeDef,
+    _OptionalListMulticastGroupsByFuotaTaskRequestRequestTypeDef,
+):
+    pass
+
+
+ListMulticastGroupsByFuotaTaskResponseTypeDef = TypedDict(
+    "ListMulticastGroupsByFuotaTaskResponseTypeDef",
+    {
+        "NextToken": str,
+        "MulticastGroupList": List["MulticastGroupByFuotaTaskTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListMulticastGroupsRequestRequestTypeDef = TypedDict(
+    "ListMulticastGroupsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListMulticastGroupsResponseTypeDef = TypedDict(
+    "ListMulticastGroupsResponseTypeDef",
+    {
+        "NextToken": str,
+        "MulticastGroupList": List["MulticastGroupTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListPartnerAccountsRequestRequestTypeDef = TypedDict(
     "ListPartnerAccountsRequestRequestTypeDef",
     {
@@ -926,6 +1308,8 @@ ListWirelessDevicesRequestRequestTypeDef = TypedDict(
         "DeviceProfileId": str,
         "ServiceProfileId": str,
         "WirelessDeviceType": WirelessDeviceTypeType,
+        "FuotaTaskId": str,
+        "MulticastGroupId": str,
     },
     total=False,
 )
@@ -1005,7 +1389,7 @@ LoRaWANDeviceProfileTypeDef = TypedDict(
         "RxDrOffset1": int,
         "RxDataRate2": int,
         "RxFreq2": int,
-        "FactoryPresetFreqsList": List[int],
+        "FactoryPresetFreqsList": Sequence[int],
         "MaxEirp": int,
         "MaxDutyCycle": int,
         "RfRegion": str,
@@ -1025,6 +1409,24 @@ LoRaWANDeviceTypeDef = TypedDict(
         "OtaaV1_0_x": "OtaaV1_0_xTypeDef",
         "AbpV1_1": "AbpV1_1TypeDef",
         "AbpV1_0_x": "AbpV1_0_xTypeDef",
+        "FPorts": "FPortsTypeDef",
+    },
+    total=False,
+)
+
+LoRaWANFuotaTaskGetInfoTypeDef = TypedDict(
+    "LoRaWANFuotaTaskGetInfoTypeDef",
+    {
+        "RfRegion": str,
+        "StartTime": datetime,
+    },
+    total=False,
+)
+
+LoRaWANFuotaTaskTypeDef = TypedDict(
+    "LoRaWANFuotaTaskTypeDef",
+    {
+        "RfRegion": SupportedRfRegionType,
     },
     total=False,
 )
@@ -1052,9 +1454,9 @@ LoRaWANGatewayTypeDef = TypedDict(
     {
         "GatewayEui": str,
         "RfRegion": str,
-        "JoinEuiFilters": List[List[str]],
-        "NetIdFilters": List[str],
-        "SubBands": List[int],
+        "JoinEuiFilters": Sequence[Sequence[str]],
+        "NetIdFilters": Sequence[str],
+        "SubBands": Sequence[int],
     },
     total=False,
 )
@@ -1103,6 +1505,45 @@ LoRaWANListDeviceTypeDef = TypedDict(
     total=False,
 )
 
+LoRaWANMulticastGetTypeDef = TypedDict(
+    "LoRaWANMulticastGetTypeDef",
+    {
+        "RfRegion": SupportedRfRegionType,
+        "DlClass": DlClassType,
+        "NumberOfDevicesRequested": int,
+        "NumberOfDevicesInGroup": int,
+    },
+    total=False,
+)
+
+LoRaWANMulticastMetadataTypeDef = TypedDict(
+    "LoRaWANMulticastMetadataTypeDef",
+    {
+        "FPort": int,
+    },
+    total=False,
+)
+
+LoRaWANMulticastSessionTypeDef = TypedDict(
+    "LoRaWANMulticastSessionTypeDef",
+    {
+        "DlDr": int,
+        "DlFreq": int,
+        "SessionStartTime": datetime,
+        "SessionTimeout": int,
+    },
+    total=False,
+)
+
+LoRaWANMulticastTypeDef = TypedDict(
+    "LoRaWANMulticastTypeDef",
+    {
+        "RfRegion": SupportedRfRegionType,
+        "DlClass": DlClassType,
+    },
+    total=False,
+)
+
 LoRaWANSendDataToDeviceTypeDef = TypedDict(
     "LoRaWANSendDataToDeviceTypeDef",
     {
@@ -1119,6 +1560,14 @@ LoRaWANServiceProfileTypeDef = TypedDict(
     total=False,
 )
 
+LoRaWANStartFuotaTaskTypeDef = TypedDict(
+    "LoRaWANStartFuotaTaskTypeDef",
+    {
+        "StartTime": Union[datetime, str],
+    },
+    total=False,
+)
+
 LoRaWANUpdateDeviceTypeDef = TypedDict(
     "LoRaWANUpdateDeviceTypeDef",
     {
@@ -1148,11 +1597,38 @@ LoRaWANUpdateGatewayTaskEntryTypeDef = TypedDict(
     total=False,
 )
 
+MulticastGroupByFuotaTaskTypeDef = TypedDict(
+    "MulticastGroupByFuotaTaskTypeDef",
+    {
+        "Id": str,
+    },
+    total=False,
+)
+
+MulticastGroupTypeDef = TypedDict(
+    "MulticastGroupTypeDef",
+    {
+        "Id": str,
+        "Arn": str,
+        "Name": str,
+    },
+    total=False,
+)
+
+MulticastWirelessMetadataTypeDef = TypedDict(
+    "MulticastWirelessMetadataTypeDef",
+    {
+        "LoRaWAN": "LoRaWANMulticastMetadataTypeDef",
+    },
+    total=False,
+)
+
 OtaaV1_0_xTypeDef = TypedDict(
     "OtaaV1_0_xTypeDef",
     {
         "AppKey": str,
         "AppEui": str,
+        "GenAppKey": str,
     },
     total=False,
 )
@@ -1167,6 +1643,14 @@ OtaaV1_1TypeDef = TypedDict(
     total=False,
 )
 
+ProximityEventConfigurationTypeDef = TypedDict(
+    "ProximityEventConfigurationTypeDef",
+    {
+        "Sidewalk": "SidewalkEventNotificationConfigurationsTypeDef",
+    },
+    total=False,
+)
+
 PutResourceLogLevelRequestRequestTypeDef = TypedDict(
     "PutResourceLogLevelRequestRequestTypeDef",
     {
@@ -1190,11 +1674,28 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
 
+SendDataToMulticastGroupRequestRequestTypeDef = TypedDict(
+    "SendDataToMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+        "PayloadData": str,
+        "WirelessMetadata": "MulticastWirelessMetadataTypeDef",
+    },
+)
+
+SendDataToMulticastGroupResponseTypeDef = TypedDict(
+    "SendDataToMulticastGroupResponseTypeDef",
+    {
+        "MessageId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredSendDataToWirelessDeviceRequestRequestTypeDef = TypedDict(
     "_RequiredSendDataToWirelessDeviceRequestRequestTypeDef",
     {
@@ -1290,6 +1791,7 @@ SidewalkDeviceMetadataTypeDef = TypedDict(
 SidewalkDeviceTypeDef = TypedDict(
     "SidewalkDeviceTypeDef",
     {
+        "AmazonId": str,
         "SidewalkId": str,
         "SidewalkManufacturingSn": str,
         "DeviceCertificates": List["CertificateListTypeDef"],
@@ -1297,6 +1799,14 @@ SidewalkDeviceTypeDef = TypedDict(
     total=False,
 )
 
+SidewalkEventNotificationConfigurationsTypeDef = TypedDict(
+    "SidewalkEventNotificationConfigurationsTypeDef",
+    {
+        "AmazonIdEventTopic": EventNotificationTopicStatusType,
+    },
+    total=False,
+)
+
 SidewalkListDeviceTypeDef = TypedDict(
     "SidewalkListDeviceTypeDef",
     {
@@ -1325,11 +1835,86 @@ SidewalkUpdateAccountTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef",
+    {
+        "QueryString": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class StartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef(
+    _RequiredStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef,
+    _OptionalStartBulkAssociateWirelessDeviceWithMulticastGroupRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef",
+    {
+        "QueryString": str,
+        "Tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class StartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef(
+    _RequiredStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef,
+    _OptionalStartBulkDisassociateWirelessDeviceFromMulticastGroupRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredStartFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredStartFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalStartFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalStartFuotaTaskRequestRequestTypeDef",
+    {
+        "LoRaWAN": "LoRaWANStartFuotaTaskTypeDef",
+    },
+    total=False,
+)
+
+
+class StartFuotaTaskRequestRequestTypeDef(
+    _RequiredStartFuotaTaskRequestRequestTypeDef, _OptionalStartFuotaTaskRequestRequestTypeDef
+):
+    pass
+
+
+StartMulticastGroupSessionRequestRequestTypeDef = TypedDict(
+    "StartMulticastGroupSessionRequestRequestTypeDef",
+    {
+        "Id": str,
+        "LoRaWAN": "LoRaWANMulticastSessionTypeDef",
+    },
+)
+
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -1360,7 +1945,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
@@ -1388,16 +1973,65 @@ class UpdateDestinationRequestRequestTypeDef(
     pass
 
 
+_RequiredUpdateFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateFuotaTaskRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalUpdateFuotaTaskRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateFuotaTaskRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "LoRaWAN": "LoRaWANFuotaTaskTypeDef",
+        "FirmwareUpdateImage": str,
+        "FirmwareUpdateRole": str,
+    },
+    total=False,
+)
+
+
+class UpdateFuotaTaskRequestRequestTypeDef(
+    _RequiredUpdateFuotaTaskRequestRequestTypeDef, _OptionalUpdateFuotaTaskRequestRequestTypeDef
+):
+    pass
+
+
 UpdateLogLevelsByResourceTypesRequestRequestTypeDef = TypedDict(
     "UpdateLogLevelsByResourceTypesRequestRequestTypeDef",
     {
         "DefaultLogLevel": LogLevelType,
-        "WirelessDeviceLogOptions": List["WirelessDeviceLogOptionTypeDef"],
-        "WirelessGatewayLogOptions": List["WirelessGatewayLogOptionTypeDef"],
+        "WirelessDeviceLogOptions": Sequence["WirelessDeviceLogOptionTypeDef"],
+        "WirelessGatewayLogOptions": Sequence["WirelessGatewayLogOptionTypeDef"],
     },
     total=False,
 )
 
+_RequiredUpdateMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateMulticastGroupRequestRequestTypeDef",
+    {
+        "Id": str,
+    },
+)
+_OptionalUpdateMulticastGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateMulticastGroupRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "LoRaWAN": "LoRaWANMulticastTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateMulticastGroupRequestRequestTypeDef(
+    _RequiredUpdateMulticastGroupRequestRequestTypeDef,
+    _OptionalUpdateMulticastGroupRequestRequestTypeDef,
+):
+    pass
+
+
 UpdatePartnerAccountRequestRequestTypeDef = TypedDict(
     "UpdatePartnerAccountRequestRequestTypeDef",
     {
@@ -1407,6 +2041,31 @@ UpdatePartnerAccountRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateResourceEventConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateResourceEventConfigurationRequestRequestTypeDef",
+    {
+        "Identifier": str,
+        "IdentifierType": Literal["PartnerAccountId"],
+    },
+)
+_OptionalUpdateResourceEventConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateResourceEventConfigurationRequestRequestTypeDef",
+    {
+        "PartnerType": Literal["Sidewalk"],
+        "DeviceRegistrationState": "DeviceRegistrationStateEventConfigurationTypeDef",
+        "Proximity": "ProximityEventConfigurationTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateResourceEventConfigurationRequestRequestTypeDef(
+    _RequiredUpdateResourceEventConfigurationRequestRequestTypeDef,
+    _OptionalUpdateResourceEventConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredUpdateWirelessDeviceRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateWirelessDeviceRequestRequestTypeDef",
     {
@@ -1443,8 +2102,8 @@ _OptionalUpdateWirelessGatewayRequestRequestTypeDef = TypedDict(
     {
         "Name": str,
         "Description": str,
-        "JoinEuiFilters": List[List[str]],
-        "NetIdFilters": List[str],
+        "JoinEuiFilters": Sequence[Sequence[str]],
+        "NetIdFilters": Sequence[str],
     },
     total=False,
 )
@@ -1518,6 +2177,9 @@ WirelessDeviceStatisticsTypeDef = TypedDict(
         "LastUplinkReceivedAt": str,
         "LoRaWAN": "LoRaWANListDeviceTypeDef",
         "Sidewalk": "SidewalkListDeviceTypeDef",
+        "FuotaDeviceStatus": FuotaDeviceStatusType,
+        "MulticastDeviceStatus": str,
+        "McGroupId": int,
     },
     total=False,
 )
